# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "6.0.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_third_party_login_p_99d6dd import AddThirdPartyLoginPlatformCredentialV3
from .delete_third_party_logi_e29526 import DeleteThirdPartyLoginPlatformCredentialV3
from .delete_third_party_logi_e59b10 import DeleteThirdPartyLoginPlatformDomainV3
from .retrieve_active_oidc_cl_08c243 import RetrieveActiveOIDCClientsPublicV3
from .retrieve_all_active_thi_cf6883 import (
    RetrieveAllActiveThirdPartyLoginPlatformCredentialPublicV3,
)
from .retrieve_all_active_thi_9dd8d4 import (
    RetrieveAllActiveThirdPartyLoginPlatformCredentialV3,
)
from .retrieve_all_third_part_cc58d5 import (
    RetrieveAllThirdPartyLoginPlatformCredentialV3,
)
from .retrieve_third_party_lo_3cce91 import RetrieveThirdPartyLoginPlatformCredentialV3
from .update_third_party_logi_d9dd29 import UpdateThirdPartyLoginPlatformCredentialV3
from .update_third_party_logi_85d26c import UpdateThirdPartyLoginPlatformDomainV3
