# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Event Log Service."""

__version__ = "2.0.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# event
from .wrappers import get_event_by_event_id_handler
from .wrappers import get_event_by_event_id_handler_async
from .wrappers import get_event_by_event_type_and_event_id_handler
from .wrappers import get_event_by_event_type_and_event_id_handler_async
from .wrappers import get_event_by_event_type_handler
from .wrappers import get_event_by_event_type_handler_async
from .wrappers import get_event_by_namespace_handler
from .wrappers import get_event_by_namespace_handler_async
from .wrappers import get_event_by_user_event_id_and_event_type_handler
from .wrappers import get_event_by_user_event_id_and_event_type_handler_async
from .wrappers import get_event_by_user_id_and_event_id_handler
from .wrappers import get_event_by_user_id_and_event_id_handler_async
from .wrappers import get_event_by_user_id_and_event_type_handler
from .wrappers import get_event_by_user_id_and_event_type_handler_async
from .wrappers import get_event_by_user_id_handler
from .wrappers import get_event_by_user_id_handler_async
from .wrappers import post_event_handler
from .wrappers import post_event_handler_async

# event_descriptions
from .wrappers import agent_type_description_handler
from .wrappers import agent_type_description_handler_async
from .wrappers import event_id_description_handler
from .wrappers import event_id_description_handler_async
from .wrappers import event_level_description_handler
from .wrappers import event_level_description_handler_async
from .wrappers import event_type_description_handler
from .wrappers import event_type_description_handler_async
from .wrappers import specific_agent_type_description_handler
from .wrappers import specific_agent_type_description_handler_async
from .wrappers import specific_event_id_description_handler
from .wrappers import specific_event_id_description_handler_async
from .wrappers import specific_event_level_description_handler
from .wrappers import specific_event_level_description_handler_async
from .wrappers import specific_event_type_description_handler
from .wrappers import specific_event_type_description_handler_async
from .wrappers import specific_ux_description_handler
from .wrappers import specific_ux_description_handler_async
from .wrappers import ux_name_description_handler
from .wrappers import ux_name_description_handler_async

# event_registry
from .wrappers import get_registered_event_id_handler
from .wrappers import get_registered_event_id_handler_async
from .wrappers import get_registered_events_by_event_type_handler
from .wrappers import get_registered_events_by_event_type_handler_async
from .wrappers import get_registered_events_handler
from .wrappers import get_registered_events_handler_async
from .wrappers import register_event_handler
from .wrappers import register_event_handler_async
from .wrappers import unregister_event_id_handler
from .wrappers import unregister_event_id_handler_async
from .wrappers import update_event_registry_handler
from .wrappers import update_event_registry_handler_async

# event_v2
from .wrappers import get_event_specific_user_v2_handler
from .wrappers import get_event_specific_user_v2_handler_async
from .wrappers import get_public_edit_history
from .wrappers import get_public_edit_history_async
from .wrappers import get_user_events_v2_public
from .wrappers import get_user_events_v2_public_async
from .wrappers import query_event_stream_handler
from .wrappers import query_event_stream_handler_async

# user_information
from .wrappers import delete_user_activities_handler
from .wrappers import delete_user_activities_handler_async
from .wrappers import get_user_activities_handler
from .wrappers import get_user_activities_handler_async
from .wrappers import last_user_activity_time_handler
from .wrappers import last_user_activity_time_handler_async
