# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "6.0.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_ban_device_v4 import AdminBanDeviceV4
from .admin_decrypt_device_v4 import AdminDecryptDeviceV4
from .admin_generate_report_v4 import AdminGenerateReportV4
from .admin_get_banned_devices_v4 import AdminGetBannedDevicesV4
from .admin_get_device_ban_v4 import AdminGetDeviceBanV4
from .admin_get_device_bans_v4 import AdminGetDeviceBansV4
from .admin_get_device_types_v4 import AdminGetDeviceTypesV4
from .admin_get_devices_by_user_v4 import AdminGetDevicesByUserV4
from .admin_get_user_device_bans_v4 import AdminGetUserDeviceBansV4
from .admin_get_users_by_device_v4 import AdminGetUsersByDeviceV4
from .admin_unban_device_v4 import AdminUnbanDeviceV4
from .admin_update_device_ban_v4 import AdminUpdateDeviceBanV4
