# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "1.29.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_localized_policy_b58242 import CreateLocalizedPolicyVersion1
from .request_presigned_url_1 import RequestPresignedURL1
from .retrieve_localized_poli_4a4859 import RetrieveLocalizedPolicyVersions1
from .retrieve_single_localiz_f21ac4 import RetrieveSingleLocalizedPolicyVersion1
from .retrieve_single_localiz_480659 import RetrieveSingleLocalizedPolicyVersion3
from .set_default_policy_1 import SetDefaultPolicy1
from .update_localized_policy_b28b13 import UpdateLocalizedPolicyVersion1
