# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Event Log Service."""

__version__ = "2.0.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .agent_type_description_handler import AgentTypeDescriptionHandler
from .event_id_description_handler import EventIDDescriptionHandler
from .event_level_description_9599c9 import EventLevelDescriptionHandler
from .event_type_description_handler import EventTypeDescriptionHandler
from .specific_agent_type_des_abc470 import SpecificAgentTypeDescriptionHandler
from .specific_event_id_descr_a3e19b import SpecificEventIDDescriptionHandler
from .specific_event_level_de_346d03 import SpecificEventLevelDescriptionHandler
from .specific_event_type_des_d1ea80 import SpecificEventTypeDescriptionHandler
from .specific_ux_description_86d7b4 import SpecificUXDescriptionHandler
from .ux_name_description_handler import UXNameDescriptionHandler
