# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Event Log Service."""

__version__ = "2.0.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_agent_type import ModelsAgentType
from .models_event import ModelsEvent
from .models_event_id import ModelsEventID
from .models_event_level import ModelsEventLevel
from .models_event_registry import ModelsEventRegistry
from .models_event_response import ModelsEventResponse
from .models_event_response_v2 import ModelsEventResponseV2
from .models_event_type import ModelsEventType
from .models_event_v2 import ModelsEventV2
from .models_generic_query_payload import ModelsGenericQueryPayload
from .models_multiple_agent_type import ModelsMultipleAgentType
from .models_multiple_event_id import ModelsMultipleEventID
from .models_multiple_event_level import ModelsMultipleEventLevel
from .models_multiple_event_type import ModelsMultipleEventType
from .models_multiple_ux import ModelsMultipleUX
from .models_pagination import ModelsPagination
from .models_paging import ModelsPaging
from .models_user_last_activity import ModelsUserLastActivity
from .models_ux import ModelsUX
