# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Fleet Command."""

__version__ = "0.1.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .api_account_create_request import ApiAccountCreateRequest
from .api_account_create_response import ApiAccountCreateResponse
from .api_account_link_request import ApiAccountLinkRequest
from .api_account_link_response import ApiAccountLinkResponse
from .api_account_link_token_response import ApiAccountLinkTokenResponse
from .api_account_response import ApiAccountResponse
from .api_available_instance_types_response import ApiAvailableInstanceTypesResponse
from .api_ds_history_event import ApiDSHistoryEvent
from .api_ds_history_list import ApiDSHistoryList
from .api_ds_host_configuration import ApiDSHostConfiguration
from .api_fleet_claim_by_keys_req import ApiFleetClaimByKeysReq
from .api_fleet_claim_req import ApiFleetClaimReq
from .api_fleet_claim_response import ApiFleetClaimResponse
from .api_fleet_create_response import ApiFleetCreateResponse
from .api_fleet_get_response import ApiFleetGetResponse
from .api_fleet_list_item_response import ApiFleetListItemResponse
from .api_fleet_list_response import ApiFleetListResponse
from .api_fleet_parameters import ApiFleetParameters
from .api_fleet_regional_server_counts import ApiFleetRegionalServerCounts
from .api_fleet_server_history_event_response import ApiFleetServerHistoryEventResponse
from .api_fleet_server_history_response import ApiFleetServerHistoryResponse
from .api_fleet_server_info_response import ApiFleetServerInfoResponse
from .api_fleet_servers_response import ApiFleetServersResponse
from .api_image_deployment_profile import ApiImageDeploymentProfile
from .api_image_details import ApiImageDetails
from .api_image_list import ApiImageList
from .api_image_list_item import ApiImageListItem
from .api_image_update import ApiImageUpdate
from .api_instance_type_description_response import ApiInstanceTypeDescriptionResponse
from .api_port_configuration import ApiPortConfiguration
from .api_referencing_fleet import ApiReferencingFleet
from .api_region_config import ApiRegionConfig
from .api_regions_response import ApiRegionsResponse
from .api_timeout import ApiTimeout
from .response_error_response import ResponseErrorResponse
