# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Browser Service."""

__version__ = "1.15.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._session import add_player_to_session
from ._session import add_player_to_session_async
from ._session import admin_delete_session
from ._session import admin_delete_session_async
from ._session import admin_get_session
from ._session import admin_get_session_async
from ._session import admin_query_session
from ._session import admin_query_session_async
from ._session import admin_search_sessions_v2
from ._session import admin_search_sessions_v2_async
from ._session import create_session
from ._session import create_session_async
from ._session import delete_session
from ._session import delete_session_async
from ._session import delete_session_local_ds
from ._session import delete_session_local_ds_async
from ._session import get_active_custom_game_sessions
from ._session import get_active_custom_game_sessions_async
from ._session import get_active_matchmaking_game_sessions
from ._session import get_active_matchmaking_game_sessions_async
from ._session import get_recent_player
from ._session import get_recent_player_async
from ._session import get_session
from ._session import get_session_async
from ._session import get_session_by_user_i_ds
from ._session import get_session_by_user_i_ds_async
from ._session import get_session_history_detailed
from ._session import get_session_history_detailed_async
from ._session import get_total_active_session
from ._session import get_total_active_session_async
from ._session import join_session
from ._session import join_session_async
from ._session import remove_player_from_session
from ._session import remove_player_from_session_async
from ._session import update_session
from ._session import update_session_async
from ._session import update_settings
from ._session import update_settings_async
from ._session import user_query_session
from ._session import user_query_session_async
