# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Social Service."""

__version__ = "2.8.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_add_stats import BulkAddStats
from .bulk_get_stat_cycle import BulkGetStatCycle
from .bulk_get_stat_cycle_1 import BulkGetStatCycle1
from .create_stat_cycle import CreateStatCycle
from .delete_stat_cycle import DeleteStatCycle
from .get_stat_cycle import GetStatCycle
from .get_stat_cycle_1 import GetStatCycle1
from .get_stat_cycles import GetStatCycles
from .get_stat_cycles import (
    CycleTypeEnum as GetStatCyclesCycleTypeEnum,
    StatusEnum as GetStatCyclesStatusEnum,
)
from .get_stat_cycles_1 import GetStatCycles1
from .get_stat_cycles_1 import (
    CycleTypeEnum as GetStatCycles1CycleTypeEnum,
    StatusEnum as GetStatCycles1StatusEnum,
)
from .stop_stat_cycle import StopStatCycle
from .update_stat_cycle import UpdateStatCycle
