# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "6.0.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_sso_login_platform__582c7e import AddSSOLoginPlatformCredential
from .delete_sso_login_platfo_2a8ff3 import DeleteSSOLoginPlatformCredentialV3
from .retrieve_all_sso_login__c73ace import RetrieveAllSSOLoginPlatformCredentialV3
from .retrieve_sso_login_plat_90c5f8 import RetrieveSSOLoginPlatformCredential
from .update_sso_platform_credential import UpdateSSOPlatformCredential
