# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.8.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._admin_concurrent_record import admin_put_game_record_concurrent_handler_v1
from ._admin_concurrent_record import admin_put_game_record_concurrent_handler_v1_async
from ._admin_concurrent_record import (
    admin_put_player_public_record_concurrent_handler_v1,
)
from ._admin_concurrent_record import (
    admin_put_player_public_record_concurrent_handler_v1_async,
)
from ._admin_concurrent_record import admin_put_player_record_concurrent_handler_v1
from ._admin_concurrent_record import (
    admin_put_player_record_concurrent_handler_v1_async,
)

from ._admin_game_record import admin_delete_game_record_handler_v1
from ._admin_game_record import admin_delete_game_record_handler_v1_async
from ._admin_game_record import admin_get_game_record_handler_v1
from ._admin_game_record import admin_get_game_record_handler_v1_async
from ._admin_game_record import admin_post_game_record_handler_v1
from ._admin_game_record import admin_post_game_record_handler_v1_async
from ._admin_game_record import admin_put_game_record_handler_v1
from ._admin_game_record import admin_put_game_record_handler_v1_async
from ._admin_game_record import list_game_records_handler_v1
from ._admin_game_record import list_game_records_handler_v1_async

from ._admin_player_record import admin_delete_player_public_record_handler_v1
from ._admin_player_record import admin_delete_player_public_record_handler_v1_async
from ._admin_player_record import admin_delete_player_record_handler_v1
from ._admin_player_record import admin_delete_player_record_handler_v1_async
from ._admin_player_record import admin_get_player_public_record_handler_v1
from ._admin_player_record import admin_get_player_public_record_handler_v1_async
from ._admin_player_record import admin_get_player_record_handler_v1
from ._admin_player_record import admin_get_player_record_handler_v1_async
from ._admin_player_record import admin_get_player_record_size_handler_v1
from ._admin_player_record import admin_get_player_record_size_handler_v1_async
from ._admin_player_record import admin_post_player_public_record_handler_v1
from ._admin_player_record import admin_post_player_public_record_handler_v1_async
from ._admin_player_record import admin_post_player_record_handler_v1
from ._admin_player_record import admin_post_player_record_handler_v1_async
from ._admin_player_record import admin_put_player_public_record_handler_v1
from ._admin_player_record import admin_put_player_public_record_handler_v1_async
from ._admin_player_record import admin_put_player_record_handler_v1
from ._admin_player_record import admin_put_player_record_handler_v1_async
from ._admin_player_record import admin_retrieve_player_records
from ._admin_player_record import admin_retrieve_player_records_async
from ._admin_player_record import bulk_get_player_record_size_handler_v1
from ._admin_player_record import bulk_get_player_record_size_handler_v1_async
from ._admin_player_record import list_player_record_handler_v1
from ._admin_player_record import list_player_record_handler_v1_async

from ._concurrent_record import put_game_record_concurrent_handler_v1
from ._concurrent_record import put_game_record_concurrent_handler_v1_async
from ._concurrent_record import put_player_public_record_concurrent_handler_v1
from ._concurrent_record import put_player_public_record_concurrent_handler_v1_async
from ._concurrent_record import put_player_record_concurrent_handler_v1
from ._concurrent_record import put_player_record_concurrent_handler_v1_async

from ._public_game_record import delete_game_record_handler_v1
from ._public_game_record import delete_game_record_handler_v1_async
from ._public_game_record import get_game_record_handler_v1
from ._public_game_record import get_game_record_handler_v1_async
from ._public_game_record import get_game_records_bulk
from ._public_game_record import get_game_records_bulk_async
from ._public_game_record import post_game_record_handler_v1
from ._public_game_record import post_game_record_handler_v1_async
from ._public_game_record import put_game_record_handler_v1
from ._public_game_record import put_game_record_handler_v1_async

from ._public_player_record import bulk_get_player_public_record_handler_v1
from ._public_player_record import bulk_get_player_public_record_handler_v1_async
from ._public_player_record import delete_player_record_handler_v1
from ._public_player_record import delete_player_record_handler_v1_async
from ._public_player_record import get_other_player_public_record_handler_v1
from ._public_player_record import get_other_player_public_record_handler_v1_async
from ._public_player_record import get_other_player_public_record_key_handler_v1
from ._public_player_record import get_other_player_public_record_key_handler_v1_async
from ._public_player_record import get_player_public_record_handler_v1
from ._public_player_record import get_player_public_record_handler_v1_async
from ._public_player_record import get_player_record_handler_v1
from ._public_player_record import get_player_record_handler_v1_async
from ._public_player_record import get_player_records_bulk_handler_v1
from ._public_player_record import get_player_records_bulk_handler_v1_async
from ._public_player_record import post_player_public_record_handler_v1
from ._public_player_record import post_player_public_record_handler_v1_async
from ._public_player_record import post_player_record_handler_v1
from ._public_player_record import post_player_record_handler_v1_async
from ._public_player_record import public_delete_player_public_record_handler_v1
from ._public_player_record import public_delete_player_public_record_handler_v1_async
from ._public_player_record import put_player_public_record_handler_v1
from ._public_player_record import put_player_public_record_handler_v1_async
from ._public_player_record import put_player_record_handler_v1
from ._public_player_record import put_player_record_handler_v1_async
from ._public_player_record import retrieve_player_records
from ._public_player_record import retrieve_player_records_async
